deepsignal
==========


Documentation
-------------

v0.1.3
-------------
fix the deadlock issue in multiprocessing

v0.1.2
-------------
add MANIFEST.in file

v0.1.1
-------------
3 modules (extract, call_mods, train) supported